<?php

namespace Modules\Qc\Http\Controllers;

use Illuminate\Support\Facades\Auth;
use Exception;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Hr\Entities\Employee;
use Modules\Qc\Entities\PackingLineQualityRecordHeader;
use Modules\Qc\Entities\PackingLineQualityRecordData;

class PackingLineQualityRecordDataController extends Controller
{
    public function save(Request $request)
    {
        try {
            $rec = new PackingLineQualityRecordHeader();
            $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');      
            $rec->trans_date = $request->get('trans_date');
            if ($rec->save()) {
                $rec_arr = $request->get("plq_data");
                for ($i = 0; $i < count($rec_arr); $i++) {
                    $plqData = json_decode($rec_arr[$i]);

                    $rec_data = new PackingLineQualityRecordData();
                    $rec_data->plqr_id = $rec->plqr_id;
                    $rec_data->hour = $plqData->hour;
                    $rec_data->seal_damage1 = $plqData->seal_damage1;
                    $rec_data->seal_damage2 = $plqData->seal_damage2;
                    $rec_data->seal_damage3 = $plqData->seal_damage3;
                    $rec_data->seal_damage4 = $plqData->seal_damage4;
                    $rec_data->seal_damage5 = $plqData->seal_damage5;
                    $rec_data->slab_damage = $plqData->slab_damage;
                    $rec_data->print_damage = $plqData->print_damage;
                    $rec_data->packing_damage = $plqData->packing_damage;
                    $rec_data->sealing_length = $plqData->sealing_length;
                    $rec_data->checked_by = $plqData->checked_by;

                    $rec_data->save();
                }
            }
            $responseBody = $this->responseBody(true, "PackingLineQualityRecordDataController", "saved", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PackingLineQualityRecordDataController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function update(Request $request, $id)
    {

        try {

            if ($this->delete($id)) {
                $rec = PackingLineQualityRecordHeader::find($id);
                $rec->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');             
                $rec->trans_date = $request->get('trans_date');
                $rec->update();

                $rec_arr = $request->get("plq_data");
                if ($rec_arr) {
                    for ($i = 0; $i < count($rec_arr); $i++) {
                        $plqData = json_decode($rec_arr[$i]);
                        $rec_data = new PackingLineQualityRecordData();
                        $rec_data->plqr_id = $rec->plqr_id;
                        $rec_data->hour = $plqData->hour;
                        $rec_data->seal_damage1 = $plqData->seal_damage1;
                        $rec_data->seal_damage2 = $plqData->seal_damage2;
                        $rec_data->seal_damage3 = $plqData->seal_damage3;
                        $rec_data->seal_damage4 = $plqData->seal_damage4;
                        $rec_data->seal_damage5 = $plqData->seal_damage5;
                        $rec_data->slab_damage = $plqData->slab_damage;
                        $rec_data->print_damage = $plqData->print_damage;
                        $rec_data->packing_damage = $plqData->packing_damage;
                        $rec_data->sealing_length = $plqData->sealing_length;
                        $rec_data->checked_by = $plqData->checked_by;
                        $rec_data->save();
                    }
                }
            }

            $responseBody = $this->responseBody(true, "PackingLineQualityRecordHeaderController", "update", true);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "PackingLineQualityRecordHeaderController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function delete($id)
    {
        try {
            $rec_data = PackingLineQualityRecordData::where('plqr_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    public function getCheckedBy()
    {
        try {
            $checkedBy =  Employee::where('department_id', '=', '13')->get();
            $responseBody = $this->responseBody(true, "PackingLineQualityRecordDataController", "getShiftData", $checkedBy);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PackingLineQualityRecordDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getPlqData($id)
    {
        try {
            $recordHead = PackingLineQualityRecordHeader::find($id);
            $recordData = PackingLineQualityRecordData::where('plqr_id', '=', $id)->get();

            foreach ($recordData as $data) {
                $sed = $data->seal_damage1 + $data->seal_damage2 + $data->seal_damage3 + $data->seal_damage4 + $data->seal_damage5;
                $total = $sed + $data->slab_damage + $data->print_damage + $data->packing_damage;
                $data->sed = $sed;
                $data->total = $total;
            }

            $recordHead->request_data = $recordData;

            $responseBody = $this->responseBody(true, "DamageCheckingRecordsDataController", "getplqData", $recordHead);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DamageCheckingRecordsDataController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }








    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
