<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\PallatizingDetailsData;
use Modules\Qc\Entities\PallatizingDetailsHeader;

class PallatizingDetailsHeaderController extends Controller
{
    public function allRecords()
    {
        try {
            $query = "SELECT
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            qc_pallatizing_details_headers.*,
            hr_employee_sites.site
        FROM
            st_products
            INNER JOIN
            pp_customer_order_plans_data
            INNER JOIN
            qc_pallatizing_details_headers
            ON
                pp_customer_order_plans_data.customer_order_plan_data_id = qc_pallatizing_details_headers.customer_order_plan_data_id AND
                st_products.product_primary_id = pp_customer_order_plans_data.product_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_pallatizing_details_headers.factory = hr_employee_sites.site_id
        GROUP BY
            qc_pallatizing_details_headers.pallatizing_id";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "pallatizing_id" => $record->pallatizing_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "date" => $record->date,
                    "factory" => $record->site,
                ]);
            }
            $responseBody = $this->responseBody(true, "PallatizingDetailsHeaderController", "allRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PallatizingDetailsHeaderController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function deleteRecord($id)
    {
        try {
            if ($this->delete($id)) {
                $rec_head = PallatizingDetailsHeader::where('pallatizing_id', '=', $id)->get();
                foreach ($rec_head as $data) {
                    $data->delete();
                }
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function delete($id) {
        try {
            $rec_data = PallatizingDetailsData::where('pallatizing_id', '=', $id)->get();
                foreach ($rec_data as $data) {
                    $data->delete();
                }
                return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    public function pallatizingReport($id)
    {
        try {
            $query1 = "SELECT
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            hr_employee_sites.site,
            qc_pallatizing_details_headers.*
        FROM
            st_products
            INNER JOIN
            pp_customer_order_plans_data
            INNER JOIN
            qc_pallatizing_details_headers
            ON
                st_products.product_primary_id = pp_customer_order_plans_data.product_id AND
                pp_customer_order_plans_data.customer_order_plan_data_id = qc_pallatizing_details_headers.customer_order_plan_data_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_pallatizing_details_headers.factory = hr_employee_sites.site_id
        WHERE
            qc_pallatizing_details_headers.pallatizing_id = {$id}";

            $records = DB::select($query1);

            $header = [
                "reference_no" => "",
                "product" => "",
                "factory_order_number" => "",
                "date" => "",
                "factory" => "",
            ];


            if ($records) {
                $header["reference_no"] = $records[0]->reference_no;
                $header["product"] = $records[0]->product_name;
                $header["factory_order_number"] = $records[0]->manufacturing_order_no;
                $header["date"] = $records[0]->date;
                $header["factory"] = $records[0]->site;
            }

            $query2 = "SELECT
            qc_pallatizing_details_data.*
        FROM
            qc_pallatizing_details_data
        WHERE
            qc_pallatizing_details_data.pallatizing_id = {$id}";

            $data = DB::select($query2);

            foreach ($data as $pallatizingData) {
                $total = $pallatizingData->l1_qty + $pallatizingData->l2_qty + $pallatizingData->l3_qty + $pallatizingData->l4_qty + $pallatizingData->l5_qty + $pallatizingData->l6_qty + $pallatizingData->l7_qty + $pallatizingData->l8_qty + $pallatizingData->l9_qty + $pallatizingData->l10_qty + $pallatizingData->l11_qty + $pallatizingData->l12_qty + $pallatizingData->l13_qty;
                $pallatizingData->total = $total;
            }

            $responseBody = $this->responseBody(true, "PallatizingDetailsHeaderController", "pallatizingReport", ["header" => $header, "body" => ["data" => $data]]);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PallatizingDetailsHeaderController", "pallatizingReport", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
